Getting Started
==================

Installation
----------------

The latest stable release of mssm can be installed from `pypi <https://pypi.org/project/mssm/\#description>`_. So to complete both steps (after installing ``conda`` - see `here <https://docs.conda.io/projects/conda/en/latest/user-guide/getting-started.html>`_ for instructions), simply run::


   conda create -n mssm_env python=3.13
   conda activate mssm_env
   pip install mssm mssmViz # 'mssmViz' only needed for plotting


For more detailed instructions see the `README <https://github.com/JoKra1/mssm>`_. Now that you have ``mssm`` installed, you can get started with the tutorial!